@@ -15,10 +15,10 @@
 #
 
 from neutron_lib import context as neutron_context
+from neutron_lib.db import api as db_api
 from oslo_log import log as logging
 from oslo_service import loopingcall
 
-from neutron.db import api as db_api
 
 from networking_odl.db import db
 
@@ -47,11 +47,10 @@ class PeriodicTask(object):
             pass
 
     @db_api.retry_if_session_inactive()
+    @db_api.CONTEXT_WRITER.savepoint
     def _set_operation(self, context, operation):
-        session = context.session
-        with db_api.autonested_transaction(session):
-            db.update_periodic_task(session, task=self.task,
-                                    operation=operation)
+        db.update_periodic_task(context, task=self.task,
+                                operation=operation)
 
     def _execute_op(self, operation, context):
         op_details = operation.__name__
@@ -62,7 +61,7 @@ class PeriodicTask(object):
             LOG.info("Starting %s phase of periodic task %s.",
                      op_details, self.task)
             self._set_operation(context, operation)
-            operation(context=context)
+            operation(context)
             LOG.info("Finished %s phase of %s task.", op_details, self.task)
         except Exception:
             LOG.exception("Failed during periodic task operation %s.",
@@ -70,21 +69,19 @@ class PeriodicTask(object):
 
     def task_already_executed_recently(self, context):
         return db.was_periodic_task_executed_recently(
-            context.session, self.task, self.interval)
+            context, self.task, self.interval)
 
     @db_api.retry_if_session_inactive()
+    @db_api.CONTEXT_WRITER.savepoint
     def _clear_and_unlock_task(self, context):
-        session = context.session
-        with db_api.autonested_transaction(session):
-            db.update_periodic_task(session, task=self.task,
-                                    operation=None)
-            db.unlock_periodic_task(session, self.task)
+        db.update_periodic_task(context, task=self.task,
+                                operation=None)
+        db.unlock_periodic_task(context, self.task)
 
     @db_api.retry_if_session_inactive()
+    @db_api.CONTEXT_WRITER.savepoint
     def _lock_task(self, context):
-        session = context.session
-        with db_api.autonested_transaction(session):
-            return db.lock_periodic_task(session, self.task)
+        return db.lock_periodic_task(context, self.task)
 
     def execute_ops(self, forced=False):
         LOG.info("Starting %s periodic task.", self.task)
