@@ -18,10 +18,10 @@ import contextlib
 
 from networking_odl.common import constants as odl_const
 from networking_odl.tests.functional import base
-from neutron.plugins.common import utils
 from neutron.services.trunk import constants
 from neutron.services.trunk import plugin as trunk_plugin
 from neutron.tests.unit.plugins.ml2 import test_plugin
+from neutron_lib.plugins import utils
 
 from oslo_utils import uuidutils
 
@@ -103,13 +103,3 @@ class TestTrunkV2Driver(base.V2DriverAdjustment, _TrunkDriverTest,
         self.trunk_plugin = trunk_plugin.TrunkPlugin()
         self.trunk_plugin.add_segmentation_type(constants.VLAN,
                                                 utils.is_valid_vlan_tag)
-
-
-class TestTrunkV1Driver(_TrunkDriverTest, test_plugin.Ml2PluginV2TestCase):
-    _mechanism_drivers = ['opendaylight']
-
-    def setUp(self):
-        super(TestTrunkV1Driver, self).setUp()
-        self.trunk_plugin = trunk_plugin.TrunkPlugin()
-        self.trunk_plugin.add_segmentation_type(constants.VLAN,
-                                                utils.is_valid_vlan_tag)
