@@ -20,7 +20,6 @@ import mock
 import requests
 import testscenarios
 
-from neutron.db import api as db_api
 from neutron.db.models import securitygroup
 from neutron.db import segments_db
 from neutron.plugins.ml2 import plugin
@@ -28,6 +27,7 @@ from neutron.tests.unit import testlib_api
 from neutron_lib.api.definitions import multiprovidernet as mpnet_apidef
 from neutron_lib.api.definitions import provider_net as providernet
 from neutron_lib import constants as n_constants
+from neutron_lib.db import api as db_api
 from neutron_lib.plugins import constants as plugin_const
 from neutron_lib.plugins import directory
 from oslo_config import cfg
@@ -333,12 +333,12 @@ class OpenDaylightMechanismDriverTestCase(base_v2.OpenDaylightConfigBase):
                     plugin_context.session.add(sg)
                     sg_dict = dict(sg)
                     sg_dict['security_group_rules'] = []
-                    with db_api.context_manager.writer.using(plugin_context):
+                    with db_api.CONTEXT_WRITER.using(plugin_context):
                         self.mech.sync_from_callback_precommit(
                             plugin_context, operation, res_type, res_id,
                             context_, security_group=sg_dict)
                 if operation == odl_const.ODL_DELETE:
-                    with db_api.context_manager.writer.using(plugin_context):
+                    with db_api.CONTEXT_WRITER.using(plugin_context):
                         self.mech.sync_from_callback_precommit(
                             plugin_context, operation, res_type, res_id,
                             context_,
@@ -347,19 +347,19 @@ class OpenDaylightMechanismDriverTestCase(base_v2.OpenDaylightConfigBase):
                             security_group_rule_ids=[SG_RULE_FAKE_ID])
             elif (object_type == odl_const.ODL_SG_RULE and
                   operation == odl_const.ODL_DELETE):
-                with db_api.context_manager.writer.using(plugin_context):
+                with db_api.CONTEXT_WRITER.using(plugin_context):
                     self.mech.sync_from_callback_precommit(
                         plugin_context, operation, res_type, res_id,
                         context_, security_group_id=SG_FAKE_ID)
             else:
-                with db_api.context_manager.writer.using(plugin_context):
+                with db_api.CONTEXT_WRITER.using(plugin_context):
                     self.mech.sync_from_callback_precommit(
                         plugin_context, operation, res_type, res_id,
                         context_)
         else:
             method = getattr(self.mech, '%s_%s_precommit' % (operation,
                                                              object_type))
-            with db_api.context_manager.writer.using(context):
+            with db_api.CONTEXT_WRITER.using(context):
                 method(context)
 
     def _test_operation_object(self, operation, object_type):
@@ -637,7 +637,7 @@ class OpenDaylightMechanismDriverTestCase(base_v2.OpenDaylightConfigBase):
             sg.security_group_rules = [rule]
             kwargs = {'security_group': sg,
                       'security_group_rule_ids': [SG_RULE_FAKE_ID]}
-            with db_api.context_manager.writer.using(self.db_context):
+            with db_api.CONTEXT_WRITER.using(self.db_context):
                 self.mech.sync_from_callback_precommit(
                     self.db_context, odl_const.ODL_DELETE,
                     callback._RESOURCE_MAPPING[odl_const.ODL_SG],
@@ -662,7 +662,7 @@ class OpenDaylightMechanismDriverTestCase(base_v2.OpenDaylightConfigBase):
             rule.security_group_id = SG_FAKE_ID
             kwargs = {'security_group_rule_id': SG_RULE_FAKE_ID,
                       'security_group_id': SG_FAKE_ID}
-            with db_api.context_manager.writer.using(self.db_context):
+            with db_api.CONTEXT_WRITER.using(self.db_context):
                 self.mech.sync_from_callback_precommit(
                     self.db_context, odl_const.ODL_DELETE,
                     callback._RESOURCE_MAPPING[odl_const.ODL_SG_RULE],
