@@ -20,11 +20,13 @@ import logging
 import mock
 from pecan import util as p_util
 
-from neutron.db import api as db_api
 from neutron.tests.unit.testlib_api import SqlTestCaseLight
-from neutron_lib import context
+from neutron_lib import context as neutron_context
+from neutron_lib.db import api as db_api
+from neutron_lib import fixture as lib_fixtures
 from oslo_config import fixture as config_fixture
 from oslo_db import exception as db_exc
+import sqlalchemy
 from sqlalchemy.orm import exc
 
 from networking_odl.common import constants
@@ -50,29 +52,46 @@ class ODLBaseDbTestCase(SqlTestCaseLight):
 
     def setUp(self):
         super(ODLBaseDbTestCase, self).setUp()
-        self.db_context = context.get_admin_context()
-        self.db_session = self.db_context.session
-        self.addCleanup(self._db_cleanup)
+        self.db_context = neutron_context.get_admin_context()
         self.cfg = self.useFixture(config_fixture.Config())
         self.cfg.config(completed_rows_retention=-1, group='ml2_odl')
+        self._setup_retry_tracker_table()
+
+    def _setup_retry_tracker_table(self):
+        metadata = sqlalchemy.MetaData()
+        self.retry_table = sqlalchemy.Table(
+            'retry_tracker', metadata,
+            sqlalchemy.Column(
+                'id', sqlalchemy.Integer,
+                autoincrement=True,
+                primary_key=True,
+            ),
+        )
+        metadata.create_all(self.engine)
+        self.addCleanup(metadata.drop_all, self.engine)
+
+        class RetryTracker(object):
+            pass
+
+        sqlalchemy.orm.mapper(RetryTracker, self.retry_table)
+        self.retry_tracker = RetryTracker
 
     def _db_cleanup(self):
-        self.db_session.query(models.OpenDaylightJournal).delete()
-        self.db_session.query(models.OpenDaylightPeriodicTask).delete()
+        self.db_context.session.query(models.OpenDaylightJournal).delete()
+        self.db_context.session.query(models.OpenDaylightPeriodicTask).delete()
         row0 = models.OpenDaylightPeriodicTask(
             task='maintenance', state=constants.PENDING)
         row1 = models.OpenDaylightPeriodicTask(
             task='hostconfig', state=constants.PENDING)
-        self.db_session.merge(row0)
-        self.db_session.merge(row1)
-        self.db_session.flush()
+        self.db_context.session.merge(row0)
+        self.db_context.session.merge(row1)
+        self.db_context.session.flush()
 
-    # NOTE(mpeterson): make retries faster so it doesn't take a lot.
-    @mock.patch.multiple(db_api._retry_db_errors,
-                         retry_interval=RETRY_INTERVAL,
-                         max_retries=RETRY_MAX)
-    def _test_db_exceptions_handled(self, method, mock_object,
-                                    receives_context, expect_retries):
+    def _test_db_exceptions_handled(self, method, mock_object, expect_retries):
+        # NOTE(mpeterson): make retries faster so it doesn't take a lot.
+        retry_fixture = lib_fixtures.DBRetryErrorsFixture(
+            max_retries=RETRY_MAX, retry_interval=RETRY_INTERVAL)
+        retry_fixture.setUp()
         # NOTE(mpeterson): this test is very verbose, disabling logging
         logging.disable(logging.CRITICAL)
         self.addCleanup(logging.disable, logging.NOTSET)
@@ -93,14 +112,18 @@ class ODLBaseDbTestCase(SqlTestCaseLight):
         mock_arg.__lt__.return_value = True
         args = (mock_arg,) * args_number
 
-        def _assertRaises(exceptions, method, *args, **kwargs):
+        def _assertRaises(exceptions, method, context, *args, **kwargs):
             try:
-                method(*args, **kwargs)
+                method(context, *args, **kwargs)
             except Exception as e:
                 if not isinstance(e, exceptions):
                     raise e
 
-                session = args[0].session if receives_context else args[0]
+                # TODO(mpeterson): For now the check with session.is_active is
+                # accepted, but when the enginefacade is the only accepted
+                # pattern then it should be changed to check that a session is
+                # attached to the context
+                session = context.session
 
                 if session.is_active and isinstance(e, _InnerException):
                     self.assertTrue(getattr(e, '_RETRY_EXCEEDED', False))
@@ -118,37 +141,52 @@ class ODLBaseDbTestCase(SqlTestCaseLight):
             _e = e
 
         expected_retries = RETRY_MAX if expect_retries else 0
-        db_object = self.db_context if receives_context else self.db_session
 
+        # TODO(mpeterson): Make this an int when Py2 is no longer supported
+        # and use the `nonlocal` directive
+        retry_counter = [0]
         for exception in exceptions:
-            mock_object.side_effect = exception(_e)
+            def increase_retry_counter_and_except(*args, **kwargs):
+                retry_counter[0] += 1
+                self.db_context.session.add(self.retry_tracker())
+                self.db_context.session.flush()
+                raise exception(_e)
+            mock_object.side_effect = increase_retry_counter_and_except
 
             _assertRaises((exception, _InnerException), method,
-                          db_object, *args)
+                          self.db_context, *args)
             self.assertEqual(expected_retries, mock_object.call_count - 1)
             mock_object.reset_mock()
 
-    def _test_retry_exceptions(self, method, mock_object, receives_context,
-                               assert_begin_transaction=True):
-        # NOTE(mpeterson): the reason we test for begining of transactions is
-        # that it's not possible to retry without a new transaction or a
-        # savepoint.
-        with mock.patch.object(self.db_session, 'begin',
-                               side_effect=self.db_session.begin) as m:
-            self._test_db_exceptions_handled(method, mock_object,
-                                             receives_context, True)
-            # NOTE(mpeterson): RETRIABLE * 3 when expect_retries=True since
-            # it will retry twice as per the test, plus the original call.
-            if assert_begin_transaction:
-                self.assertEqual(m.call_count,
-                                 len(RETRIABLE_EXCEPTIONS) * (RETRY_MAX + 1))
+        retry_fixture.cleanUp()
+        return retry_counter[0]
 
-            if receives_context:
-                with self.db_session.begin():
-                    m.reset_mock()
-                    self._test_db_exceptions_handled(method, mock_object,
-                                                     receives_context, False)
-                    # NOTE(mpeterson): only once when expect_retries=False
-                    if assert_begin_transaction:
-                        self.assertEqual(m.call_count,
-                                         len(RETRIABLE_EXCEPTIONS))
+    def _assertRetryCount(self, expected_count):
+        actual_count = \
+            self.db_context.session.query(self.retry_tracker).count()
+        self.assertEqual(expected_count, actual_count)
+
+    def _test_retry_exceptions(self, method, mock_object,
+                               assert_transaction=True):
+        retries = self._test_db_exceptions_handled(method, mock_object,
+                                                   True)
+
+        if assert_transaction:
+            # It should be 0 as long as the retriable method creates save
+            # points or transactions, which is the correct behavior
+            self._assertRetryCount(0)
+            # RETRIABLE * 3 when expect_retries=True since it will retry
+            # twice as per the test, plus the original call.
+            self.assertEqual(
+                len(RETRIABLE_EXCEPTIONS) * (RETRY_MAX + 1),
+                retries
+            )
+
+        with db_api.CONTEXT_WRITER.using(self.db_context):
+            retries = self._test_db_exceptions_handled(
+                method, mock_object, False
+            )
+            if assert_transaction:
+                self._assertRetryCount(0)
+                # only once per exception when expect_retries=False
+                self.assertEqual(len(RETRIABLE_EXCEPTIONS), retries)
